@@ -5,16 +5,17 @@ from sbws.util import stem as stem_utils
 
 
 class TimedSession(requests.Session):
-    """Requests Session that sends timeout in the head and get methods.
-    """
+    """Requests Session that sends timeout in the head and get methods."""
 
     def get(self, url, **kwargs):
-        return super().get(url, timeout=getattr(self, "_timeout", None),
-                           **kwargs)
+        return super().get(
+            url, timeout=getattr(self, "_timeout", None), **kwargs
+        )
 
     def head(self, url, **kwargs):
-        return super().head(url, timeout=getattr(self, "_timeout", None),
-                            **kwargs)
+        return super().head(
+            url, timeout=getattr(self, "_timeout", None), **kwargs
+        )
 
 
 def make_session(controller, timeout):
@@ -28,8 +29,8 @@ def make_session(controller, timeout):
     if socks_info is None:
         return None
     s.proxies = {
-        'http': 'socks5h://{}:{}'.format(*socks_info),
-        'https': 'socks5h://{}:{}'.format(*socks_info),
+        "http": "socks5h://{}:{}".format(*socks_info),
+        "https": "socks5h://{}:{}".format(*socks_info),
     }
     # ``_timeout`` is not used by request's Session, but it is by TimedSession.
     s._timeout = timeout
