@@ -1,19 +1,18 @@
-from sbws.util.filelock import FileLock
-import os
 import json
+import os
+
+from sbws.util.filelock import FileLock
+
+from .json import CustomDecoder, CustomEncoder
 
 
 class State:
-    '''
-    State allows one to atomically access and update a simple state file on
-    disk across threads and across processes.
+    """
+    `json` wrapper to read a json file every time it gets a key and to write
+    to the file every time a key is set.
 
-    To put it blunty, due to limited developer time and his inability to
-    quickly find a way to safely access and update more complex data types
-    (namely, collections like list, set, and dict), you may only store simple
-    types of data as enumerated in _ALLOWED_TYPES. Keys must be strings.
-
-    Data is stored as JSON on disk in the provided file file.
+    Every time a key is got or set, the file is locked, to atomically access
+    and update the file across threads and across processes.
 
     >>> state = State('foo.state')
     >>> # state == {}
@@ -40,8 +39,8 @@ class State:
     >>> # We can do many of the same things with a State object as with a dict
     >>> for key in state: print(key)
     >>> # Prints 'linux', 'age', and 'name'
-    '''
-    _ALLOWED_TYPES = (int, float, str, bool, type(None))
+
+    """
 
     def __init__(self, fname):
         self._fname = fname
@@ -51,13 +50,13 @@ class State:
         if not os.path.exists(self._fname):
             return {}
         with FileLock(self._fname):
-            with open(self._fname, 'rt') as fd:
-                return json.load(fd)
+            with open(self._fname, "rt") as fd:
+                return json.load(fd, cls=CustomDecoder)
 
     def _write(self):
         with FileLock(self._fname):
-            with open(self._fname, 'wt') as fd:
-                return json.dump(self._state, fd, indent=4)
+            with open(self._fname, "wt") as fd:
+                return json.dump(self._state, fd, indent=4, cls=CustomEncoder)
 
     def __len__(self):
         self._state = self._read()
@@ -68,35 +67,22 @@ class State:
         Implements a dictionary ``get`` method reading and locking
         a json file.
         """
-        if not isinstance(key, str):
-            raise TypeError(
-                'Keys must be strings. %s is a %s' % (key, type(key)))
         self._state = self._read()
         return self._state.get(key, d)
 
     def __getitem__(self, key):
-        if not isinstance(key, str):
-            raise TypeError(
-                'Keys must be strings. %s is a %s' % (key, type(key)))
         self._state = self._read()
         return self._state.__getitem__(key)
 
     def __delitem__(self, key):
-        if not isinstance(key, str):
-            raise TypeError(
-                'Keys must be strings. %s is a %s' % (key, type(key)))
         self._state = self._read()
         self._state.__delitem__(key)
         self._write()
 
     def __setitem__(self, key, value):
-        if not isinstance(key, str):
-            raise TypeError(
-                'Keys must be strings. %s is a %s' % (key, type(key)))
-        if type(value) not in State._ALLOWED_TYPES:
-            raise TypeError(
-                'May only store value with type in %s, not %s' %
-                (State._ALLOWED_TYPES, type(value)))
+        # NOTE: important, read the file before setting the key,
+        # otherwise if other instances are creating other keys, they're lost.
+        self._state = self._read()
         self._state.__setitem__(key, value)
         self._write()
 
@@ -107,3 +93,18 @@ class State:
     def __contains__(self, item):
         self._state = self._read()
         return self._state.__contains__(item)
+
+    def count(self, k):
+        """
+        Returns the length if the key value is a list
+        or the sum of number if the key value is a list of list
+        or the key value
+        or None if the state doesn't have the key.
+        """
+        if self.get(k):
+            if isinstance(self._state[k], list):
+                if isinstance(self._state[k][0], list):
+                    return sum(map(lambda x: x[1], self._state[k]))
+                return len(self._state[k])
+            return self.get(k)
+        return None
